Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1164)

Unified Diff: media/audio/audio_device_thread.h

Issue 1703473002: Make AudioOutputDevice restartable and reinitializable (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@new_mixing
Patch Set: git cl format Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/audio/audio_device_thread.cc » ('j') | media/audio/audio_device_thread.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/audio/audio_device_thread.h
diff --git a/media/audio/audio_device_thread.h b/media/audio/audio_device_thread.h
index 61e5e8724ddc24b289c01c364e3491b137779462..581639a41fae3de84d3f9bf9b6f77f7d6d23f38c 100644
--- a/media/audio/audio_device_thread.h
+++ b/media/audio/audio_device_thread.h
@@ -75,13 +75,12 @@ class MEDIA_EXPORT AudioDeviceThread {
AudioDeviceThread();
~AudioDeviceThread();
- // Starts the audio thread. The thread must not already be running. If
- // |sychronized_buffers| is set, the browser expects to be notified via the
- // |socket| every time AudioDeviceThread::Process() completes.
- void Start(AudioDeviceThread::Callback* callback,
- base::SyncSocket::Handle socket,
- const char* thread_name,
- bool synchronized_buffers);
+ // Starts the audio thread and puts into wait mode. Resume() must
+ // be called to release it and actually start running. The thread must not
+ // already be started. If |sychronized_buffers| is set, the browser expects
+ // to be notified via the |socket| every time AudioDeviceThread::Process()
+ // completes.
+ void Start(const char* thread_name, bool synchronized_buffers);
// This tells the audio thread to stop and clean up the data.
// The method can stop the thread synchronously or asynchronously.
@@ -94,6 +93,16 @@ class MEDIA_EXPORT AudioDeviceThread {
// If set to NULL, function will wait for the thread to exit before returning.
void Stop(base::MessageLoop* loop_for_join);
+ // Releases the thread from wait mode so that it starts running with the given
+ // |callback| and |socket|. This will also reset the index used for
+ // sychronized buffers.
+ void Resume(AudioDeviceThread::Callback* callback,
+ base::SyncSocket::Handle socket);
+
+ // Puts the thread in the wait mode and shuts down the socket.
+ // It can be resumed again with Resume().
+ void Pause();
+
// Returns true if the thread is stopped or stopping.
bool IsStopped();
@@ -105,6 +114,7 @@ class MEDIA_EXPORT AudioDeviceThread {
// 2) We override ThreadMain to add additional on-thread initialization
// while still synchronized with SimpleThread::Start() to provide
// reliable initialization.
+ // TODO(grunell): Do we still need this extra layer?
class Thread;
base::Lock thread_lock_;
« no previous file with comments | « no previous file | media/audio/audio_device_thread.cc » ('j') | media/audio/audio_device_thread.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698